@@ -219,9 +219,7 @@ def _merge_to_n_indices(spark_session, n: int, src_folder: str, dst_folder: str,
         # no need to merge
         return src_folder, None
 
-    batch_size = max(1, int(nb_indices_on_src_folder / n))
-    n = math.ceil(nb_indices_on_src_folder / batch_size)
-    merge_batches = _batch_loader(batch_size=batch_size, nb_batches=n)
+    merge_batches = _get_merge_batches(input_size=nb_indices_on_src_folder, output_size=n)
 
     rdd = spark_session.sparkContext.parallelize(merge_batches, n)
 
@@ -249,6 +247,12 @@ def _merge_to_n_indices(spark_session, n: int, src_folder: str, dst_folder: str,
     return dst_folder, metrics_dict
 
 
+def _get_merge_batches(input_size: int, output_size: int) -> Iterator[Tuple[int, int, int]]:
+    batch_size = max(1, math.ceil(input_size / output_size))
+    merge_batches = _batch_loader(batch_size=batch_size, nb_batches=output_size)
+    return merge_batches
+
+
 def run(
     faiss_index: faiss.Index,
     embedding_reader: EmbeddingReader,
